/***************************************************************************
                          surfxp.h  -  description
                             -------------------
    begin                : Die Mr  5 19:59:18 CET 2002
    copyright            : (C) 2002 by Jrgen Bhm
    email                : aviduratas@gmx.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it.                                                                    *
 *                                                                         *
 ***************************************************************************/

#ifndef SURFXP_H
#define SURFXP_H

// include files for QT
#include <QApplication>
#include <QtWidgets>
#include <QtGui>

// application specific includes
#include "surfxpview.h"
#include "surfxpdoc.h"

/**
  * This Class is the base class for your application. It sets up the main
  * window and providing a menubar, toolbar
  * and statusbar. For the main view, an instance of class SurfxpView is
  * created which creates your view.
  */
class SurfxpApp : public QMainWindow
{
  Q_OBJECT
  
  public:
    /** construtor */
    SurfxpApp();
    /** destructor */
    ~SurfxpApp();
    /** initializes all QActions of the application */
    void initActions();
    /** initMenuBar creates the menu_bar and inserts the menuitems */
    void initMenuBar();
    /** this creates the toolbars. Change the toobar look and add new toolbars in this
     * function */
    void initToolBar();
    /** setup the statusbar */
    void initStatusBar();
    /** setup the document*/
    void initDoc();
    /** setup the mainview*/
    void initView();

    /** overloaded for Message box on last window exit */
    bool queryExit();

  public slots:

    /** generate a new document in the actual view */
    void slotFileNew();
    /** open a document */
    void slotFileOpen();
    /** save a document */
    void slotFileSave();
    /** save a document under a different filename*/
    void slotFileSaveAs();
    /** close the actual file */
    void slotFileClose();
    /** print the actual file */
    void slotFilePrint();
    /** exits the application */
    void slotFileQuit();
    /** shows control window */
    void slotControlOn();
    /** hides control window */
    void slotControlOff();
    /** toggle the toolbar*/
    void slotViewToolBar(bool toggle);
    /** toggle the statusbar*/
    void slotViewStatusBar(bool toggle);

    /** shows an about dlg*/
    void slotHelpAbout();


  private:

    /** view is the main widget which represents your working area. The View
     * class should handle all events of the view widget.  It is kept empty so
     * you can create your view according to your application's needs by
     * changing the view class.
     */
    SurfxpView *view;
    /** doc represents your actual document and is created only once. It keeps
     * information such as filename and does the serialization of your files.
     */
    SurfxpDoc *doc;
  
    /** file_menu contains all items of the menubar entry "File" */
    QMenu *fileMenu;
    /** control_menu contains all items of the menubar entry "Control" */
    QMenu *controlMenu;
    /** view_menu contains all items of the menubar entry "View" */
    QMenu *viewMenu;
    /** view_menu contains all items of the menubar entry "Help" */
    QMenu *helpMenu;
    /** the main toolbar */
    QToolBar *fileToolbar;
    /** actions for the application initialized in initActions() and used to en/disable them
      * according to your needs during the program */
    QAction *fileNew;
    QAction *fileOpen;
    QAction *fileSave;
    QAction *fileSaveAs;
    QAction *fileClose;
    QAction *filePrint;
    QAction *fileQuit;

    QAction *controlOn;
    QAction *controlOff;

    QAction *viewToolBar;
    QAction *viewStatusBar;

    QAction *helpAboutApp;
};
#endif 

